pub struct ReplicationDestinationRsyncTlsMoverSecurityContextSeLinuxOptions {
pub level: Option<String>,
pub role: Option<String>,
pub type: Option<String>,
pub user: Option<String>,
}Expand description
The SELinux context to be applied to all containers. If unspecified, the container runtime will allocate a random SELinux context for each container. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows.
Fields
level: Option<String>Level is SELinux level label that applies to the container.
role: Option<String>Role is a SELinux role label that applies to the container.
type: Option<String>Type is a SELinux type label that applies to the container.
user: Option<String>User is a SELinux user label that applies to the container.