pub struct ReplicationSourceExternal {
pub parameters: Option<BTreeMap<String, String>>,
pub provider: Option<String>,
}Expand description
external defines the configuration when using an external replication provider.
Fields
parameters: Option<BTreeMap<String, String>>parameters are provider-specific key/value configuration parameters. For more information, please see the documentation of the specific replication provider being used.
provider: Option<String>provider is the name of the external replication provider. The name should be of the form: domain.com/provider.