ReplicationSourceStatusRsync

Struct ReplicationSourceStatusRsync 

pub struct ReplicationSourceStatusRsync {
    pub address: Option<String>,
    pub port: Option<i32>,
    pub ssh_keys: Option<String>,
}
rsync contains status information for Rsync-based replication.

Fields

address: Option<String>

address is the address to connect to for incoming SSH replication connections.

port: Option<i32>

port is the SSH port to connect to for incoming SSH replication connections.

ssh_keys: Option<String>

sshKeys is the name of a Secret that contains the SSH keys to be used for authentication. If not provided in .spec.rsync.sshKeys, SSH keys will be generated and the appropriate keys for the remote side will be placed here.