This crate contains kube-rs compatible bindings for Kubernetes custom resources for the volsync.backube group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
volsync.backube/v1alpha1
ReplicationDestinationReplicationSource